@@ -1,7 +1,7 @@
 use lib '.';
 
 #BEGIN { $ENV{DBI_PUREPERL} = 2 };
-require DBI;
+#require DBI;
 
 $^W = 1;
 
@@ -24,7 +24,8 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-system ("./JFileDialogTest.pl") ? 
+$ENV{PATH} .= ':.';
+system ("JFileDialogTest.pl") ? 
 		print "not ok 2 ($@$?)\n" : print "ok 2\n";
 
 print "..done: 2 tests completed.\n";
